# CMeel SIMDe

[![PyPI version](https://badge.fury.io/py/cmeel-simde.svg)](https://pypi.org/project/cmeel-simde)

This is adding [SIMDe](https://github.com/simd-everywhere/simde) as a CMake "external project" to be exported as a wheel by cmeel.
